@@ -84,7 +84,7 @@ void DownloadUserRemoteDlg::processReturnValue(int Id,QVariant data)
 
         QFile file("/home/user/MyDocs/qtirreco/Remotes/"+ fileName);
         if (file.exists()) {
-             QMessageBox::warning(this,"Remote name already exists!","Cannot download remote, please delete remote before downloading.",
+             QMessageBox::warning(this,"Remote name already exists!","Cannot download remote, please delete remote with same name before downloading.",
                                  QMessageBox::NoButton,QMessageBox::NoButton);
         }
         else {
