@@ -29,7 +29,8 @@ QtIrreco::QtIrreco(QWidget *parent)
     //Creates empty remotes.conf file
     QFile file(DEVICECONF);
     if (!file.open(QIODevice::ReadWrite | QIODevice::Text))
-        file.close();
+        return;
+    file.close();
 
 
     lw->show();
@@ -69,7 +70,7 @@ QtIrreco::QtIrreco(QWidget *parent)
 QtIrreco::~QtIrreco()
 {
     // Stop lirc server
-    system("sudo exec /etc/init.d/lirc stop");
+    system("sudo /etc/init.d/lirc stop");
     delete ui;
 
 }
